package com.dzeio.openhealth.ui.home

import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.viewModelScope
import com.dzeio.openhealth.core.BaseViewModel
import com.dzeio.openhealth.data.water.Water
import com.dzeio.openhealth.data.water.WaterRepository
import com.dzeio.openhealth.data.weight.Weight
import com.dzeio.openhealth.data.weight.WeightRepository
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.flow.collectLatest
import kotlinx.coroutines.launch
import javax.inject.Inject

@HiltViewModel
class HomeViewModel @Inject internal constructor(
    private val weightRepository: WeightRepository,
    private val waterRepository: WaterRepository
) : BaseViewModel() {

    fun fetchWeights() = weightRepository.getWeights()

    fun lastWeight() = weightRepository.lastWeight()

    fun fetchWeight(id: Long) = weightRepository.getWeight(id)

    suspend fun deleteWeight(weight: Weight) = weightRepository.deleteWeight(weight)

    suspend fun addWeight(weight: Weight) = weightRepository.addWeight(weight)

    fun fetchTodayWater() = waterRepository.todayWater()

    val water: MutableLiveData<Water?> = MutableLiveData(null)

    fun init() {
        viewModelScope.launch {
            waterRepository.todayWater().collectLatest {
                water.postValue(it)
            }
        }
    }

    fun updateWater(water: Water) {
        viewModelScope.launch {
            waterRepository.addWater(water)
        }
    }

    fun deleteWater(item: Water) {
        viewModelScope.launch {
            waterRepository.deleteWater(item)
            water.postValue(null)
        }
    }
}