package com.dzeio.openhealth.ui.water

import android.app.Dialog
import android.os.Bundle
import android.view.LayoutInflater
import android.view.MenuItem
import android.view.Window
import androidx.core.content.ContextCompat
import androidx.core.widget.doOnTextChanged
import androidx.lifecycle.lifecycleScope
import androidx.navigation.fragment.findNavController
import androidx.navigation.fragment.navArgs
import com.dzeio.openhealth.R
import com.dzeio.openhealth.core.BaseFullscreenDialog
import com.dzeio.openhealth.databinding.DialogWaterEditWaterBinding
import com.google.android.material.dialog.MaterialAlertDialogBuilder
import dagger.hilt.android.AndroidEntryPoint

@AndroidEntryPoint
class EditWaterDialog :
    BaseFullscreenDialog<EditWaterViewModel, DialogWaterEditWaterBinding>(EditWaterViewModel::class.java) {

    override val bindingInflater: (LayoutInflater) -> DialogWaterEditWaterBinding =
        DialogWaterEditWaterBinding::inflate

    private val args: EditWaterDialogArgs by navArgs()

    override val isFullscreenLayout = true

    var newValue: Int = 0

    override fun onDialogInit(dialog: Dialog) {
        super.onDialogInit(dialog)

        dialog.requestWindowFeature(Window.FEATURE_NO_TITLE)
    }

    override fun onCreated(savedInstanceState: Bundle?) {
        super.onCreated(savedInstanceState)

        viewModel.water.observe(viewLifecycleOwner) {
            binding.editTextNumber.setText(it.value.toString())
        }
        binding.editTextNumber.doOnTextChanged { text, start, before, count ->
            newValue = text.toString().toInt()
        }

        viewModel.init(args.id)

    }

    private fun save() {
        val water = viewModel.water.value
        water?.let {
            it.value = newValue
            viewModel.save(it)
        }

        findNavController().popBackStack()
    }

    override fun onOptionsItemSelected(item: MenuItem): Boolean {
        return when (item.itemId) {
            R.id.menu_fullscreen_dialog_save -> {
                save()
                true
            }
            R.id.menu_fullscreen_dialog_delete -> {
                MaterialAlertDialogBuilder(requireContext())
                    .setTitle("Delete Water Intake?")
                    .setMessage("Are you sure you want to delete this water intake?")
                    .setPositiveButton("Yes") { _, _ ->
                        lifecycleScope.launchWhenStarted {
                            viewModel.delete()
                            findNavController().popBackStack()
                        }
                    }
                    .setIcon(
                        ContextCompat.getDrawable(
                            requireContext(),
                            R.drawable.ic_outline_delete_24
                        )
                    )
                    .setNegativeButton("No") { _, _ -> }
                    .show()
                true
            }
            else -> super.onOptionsItemSelected(item)
        }

    }
}