package com.dzeio.openhealth.utils

import android.graphics.Color
import com.github.mikephil.charting.charts.BarChart
import com.github.mikephil.charting.charts.BarLineChartBase
import com.github.mikephil.charting.charts.Chart
import com.github.mikephil.charting.charts.LineChart
import com.github.mikephil.charting.components.AxisBase
import com.github.mikephil.charting.components.Description
import com.github.mikephil.charting.components.XAxis
import com.github.mikephil.charting.data.BarLineScatterCandleBubbleData
import com.github.mikephil.charting.data.ChartData
import com.github.mikephil.charting.data.Entry
import com.github.mikephil.charting.data.LineData
import com.github.mikephil.charting.formatter.ValueFormatter
import com.github.mikephil.charting.interfaces.datasets.IBarLineScatterCandleBubbleDataSet
import com.github.mikephil.charting.interfaces.datasets.IDataSet
import com.google.android.material.color.MaterialColors
import java.text.SimpleDateFormat
import java.util.*

object GraphUtils {

    fun lineChartSetup(chart: LineChart, mainColor: Int) {
        barLineChartSetup(chart, mainColor)
    }

    fun barChartSetup(chart: BarChart, mainColor: Int) {
        barLineChartSetup(chart, mainColor)
    }

    fun <T : BarLineScatterCandleBubbleData<out IBarLineScatterCandleBubbleDataSet<out Entry>>?> barLineChartSetup(chart: BarLineChartBase<T>, mainColor: Int) {
        chart.apply {

            // Setup
            legend.isEnabled = false
            description = Description().apply { isEnabled = false }

            xAxis.apply {
                valueFormatter = object : ValueFormatter() {
                    override fun getAxisLabel(value: Float, axis: AxisBase?): String {
                        return SimpleDateFormat(
                            "yyyy-MM-dd",
                            Locale.getDefault()
                        ).format(Date(value.toLong()))
                        //return super.getAxisLabel(value, axis)
                    }
                }
                position = XAxis.XAxisPosition.BOTTOM
                setDrawGridLines(false)
                setLabelCount(3, true)
                textColor = Color.WHITE
            }

            axisLeft.apply {
                axisLineColor = mainColor
                textColor = Color.WHITE
                setLabelCount(0, true)
            }
            axisRight.apply {
                textColor = Color.WHITE
            }
            setNoDataTextColor(Color.WHITE)


            isAutoScaleMinMaxEnabled = true
            legend.isEnabled = false
            isDragEnabled = true
            isScaleYEnabled = false
            description = Description().apply { isEnabled = false }
            isScaleXEnabled = true
            setPinchZoom(false)
            //setDrawGridBackground(false)
            //setDrawBorders(false)
        }
    }
}